@@ -14,6 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+import json
 from functools import update_wrapper
 from django import VERSION as DJANGO_VERSION
 from django.conf import settings
@@ -196,6 +197,13 @@ class APIView(View):
             else:
                 login(self.request, user)
 
+    def default_error_handler(self, error_obj):
+        self.response['Content-Type'] = 'application/json'
+        self.response.content = json.dumps({
+            'status': error_obj.status_code,
+            'error': error_obj.message
+        })
+
 class DevAPIView(APIView):
     def only_accept_https(self, *args, **kwargs):
         return False
@@ -219,4 +227,4 @@ class HTMLView(View):
             context.update(self.request.GET)
             self.response = render(self.request, self.template_name, context)
         else:
-            raise ValueError, 'Template name is undefined.'
\ No newline at end of file
+            raise ValueError, 'Template name is undefined.'
