@@ -31,7 +31,7 @@ class LackOfRequiredKeyError(ViewError):
 class KeyValidationError(ViewError):
     def __init__(self, key, messages):
         status_code = 400
-        message = 'Key "%s" is invalid.' % key
+        message = ('Key "%s" is invalid.' % key + ' ' + ' '.join(messages)).strip()
         super(KeyValidationError, self).__init__(status_code, message)
         self.key = key
         self.raw_messages = messages
