@@ -25,7 +25,7 @@ from eggplant.views.decorators import validate_keys
 from eggplant.constants.settings import MAX_PAGINATION_SIZE, DEFAULT_PAGINATION_SIZE
 from eggplant.constants import defaults as eggplant_defaults
 
-class ModelCollectionAPIView(APIView):
+class ModelCollectionView(APIView):
     MODEL_CLASS = None
     DEFAULT_PAGE_SIZE = getattr(settings, DEFAULT_PAGINATION_SIZE, eggplant_defaults.EGGPLANT_DEFAULT_PAGINATION_SIZE)
 
